;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "mowie" "20250113.122"
  "Cycle Through Point-Moving Commands."
  '((emacs "28.1"))
  :url "https://codeberg.org/mekeor/mowie"
  :commit "26f605cf632579af897a85a3922bf17fac616519"
  :revdesc "26f605cf6325"
  :keywords '("convenience")
  :authors '(("Mekeor Melire" . "mekeor@posteo.de"))
  :maintainers '(("Mekeor Melire" . "mekeor@posteo.de")))
